
# Type: colocalizes with


holds between two entities that are observed to be located in the same place.

URI: [biolink:colocalizes_with](https://w3id.org/biolink/vocab/colocalizes_with)


## Domain and Range

[NamedThing](NamedThing.md) ->  <sub>0..*</sub> [NamedThing](NamedThing.md)

## Parents

 *  is_a: [coexists with](coexists_with.md)

## Children


## Used by

 * [NamedThing](NamedThing.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | RO:00002325 |
| **In Subsets:** | | translator_minimal |

